<?php
/**
 * @package   admintools
 * @copyright Copyright (c)2010-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

/** @var $this \Akeeba\AdminTools\Admin\View\TempSuperUsers\Html */

use Akeeba\AdminTools\Admin\Helper\Html;
use Akeeba\AdminTools\Admin\Model\TempSuperUsers;
use FOF30\Utils\FEFHelper\Html as FEFHtml;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;

defined('_JEXEC') || die;

// Let's check if the system plugin is correctly installed AND published
//echo $this->loadAnyTemplate('admin:com_admintools/ControlPanel/plugin_warning');

?>
<form action="index.php" method="post" name="adminForm" id="adminForm" class="akeeba-form">

	<section class="akeeba-panel--33-66 akeeba-filter-bar-container">
		<div class="akeeba-filter-bar akeeba-filter-bar--left akeeba-form-section akeeba-form--inline">
			<div class="akeeba-filter-element akeeba-form-group">
				<input type="text" name="username"
					   placeholder="<?php echo Text::_('COM_ADMINTOOLS_TEMPSUPERUSERS_LBL_USERNAME'); ?>"
					   id="filter_username" onchange="document.adminForm.submit();"
					   value="<?php echo $this->escape($this->filters['username']); ?>"
					   title="<?php echo Text::_('COM_ADMINTOOLS_TEMPSUPERUSERS_LBL_USERNAME'); ?>" />
			</div>
		</div>

		<?php echo FEFHtml::selectOrderingBackend($this->getPagination(), $this->sortFields, $this->order, $this->order_Dir) ?>
	</section>

	<table class="akeeba-table akeeba-table--striped" id="itemsList">
		<thead>
		<tr>
			<th width="32">
				<input type="checkbox" name="toggle" value="" onclick="Joomla.checkAll(this);" />
			</th>
			<th>
				<?php echo HTMLHelper::_('grid.sort', 'COM_ADMINTOOLS_TEMPSUPERUSERS_FIELD_USER_ID', 'user_id', $this->order_Dir, $this->order, 'browse'); ?>
			</th>
			<th>
				<?php echo Text::_('COM_ADMINTOOLS_TEMPSUPERUSERS_LBL_USERNAME') ?>
			</th>
			<th>
				<?php echo HTMLHelper::_('grid.sort', 'COM_ADMINTOOLS_TEMPSUPERUSERS_FIELD_EXPIRATION', 'expiration', $this->order_Dir, $this->order, 'browse'); ?>
			</th>
		</tr>
		</thead>
		<tfoot>
		<tr>
			<td colspan="11" class="center">
				<?php echo $this->pagination->getListFooter(); ?>
			</td>
		</tr>
		</tfoot>
		<tbody>
		<?php if (!(is_array($this->items) || $this->items instanceof \Countable ? count($this->items) : 0)): ?>
			<tr>
				<td colspan="6">
					<?php echo Text::_('COM_ADMINTOOLS_ERR_TEMPSUPERUSERS_NOITEMS') ?>
				</td>
			</tr>
			<tr>
				<td colspan="6">
					<a href="index.php?option=com_admintools&view=TempSuperUsers&task=add"
					   class="akeeba-btn--green--big"
					>
						<span class="akion-android-person-add"></span>
						<?php echo Text::_('COM_ADMINTOOLS_BTN_TEMPSUPERUSERS_ADD') ?>
					</a>
				</td>
			</tr>
		<?php endif; ?>
		<?php
		if ($this->items):
			$i = 0;
			/** @var TempSuperUsers $row */
			foreach ($this->items as $row):
				?>
				<tr>
					<td><?php echo HTMLHelper::_('grid.id', ++$i, $row->user_id); ?></td>
					<td>
						<a href="index.php?option=com_admintools&view=TempSuperUsers&task=edit&id=<?php echo $row->user_id ?>">
							<?php echo $this->escape($row->user_id) ?>
						</a>
					</td>
					<td>
						<?php if (empty($row->user)): ?>
							<span class="akeeba-label--red hasPopover"
								  data-title="<?= Text::_('COM_ADMINTOOLS_TEMPSUPERUSERS_LBL_INVALIDUSER') ?>"
								  data-content="<?= Text::_('COM_ADMINTOOLS_TEMPSUPERUSERS_LBL_INVALIDUSER_TIP') ?>">
							<?= Text::_('COM_ADMINTOOLS_TEMPSUPERUSERS_LBL_INVALIDUSER') ?>
						</span>
						<?php else: ?>
							<strong>
								<a href="index.php?option=com_admintools&view=TempSuperUsers&task=edit&id=<?php echo $row->user_id ?>">
									<?php echo $row->user->username ?>
								</a>
							</strong>
							<br />
							<small>
								<a href="index.php?option=com_users&task=user.edit&id=<?php echo $row->user_id ?>"
								   target="_blank">
									<?php echo $row->user->name ?> <em>(<?php echo $row->user->email ?>)</em>
								</a>
							</small>
						<?php endif; ?>
					</td>
					<td>
						<?php echo Html::localisedDate($row->expiration) ?>
					</td>
				</tr>
			<?php
			endforeach;
		endif; ?>
		</tbody>

	</table>

	<div class="akeeba-hidden-fields-container">
		<input type="hidden" name="option" id="option" value="com_admintools" />
		<input type="hidden" name="view" id="view" value="TempSuperUsers" />
		<input type="hidden" name="boxchecked" id="boxchecked" value="0" />
		<input type="hidden" name="task" id="task" value="browse" />
		<input type="hidden" name="filter_order" id="filter_order" value="<?php echo $this->escape($this->order); ?>" />
		<input type="hidden" name="filter_order_Dir" id="filter_order_Dir"
			   value="<?php echo $this->escape($this->order_Dir); ?>" />
		<input type="hidden" name="<?php echo $this->container->platform->getToken(true); ?>" value="1" />
	</div>
</form>
